summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/fcs.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpat/freecell-solver/fcs.h')
-rw-r--r--kpat/freecell-solver/fcs.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpat/freecell-solver/fcs.h b/kpat/freecell-solver/fcs.h
index 43300310..6bca557f 100644
--- a/kpat/freecell-solver/fcs.h
+++ b/kpat/freecell-solver/fcs.h
@@ -170,7 +170,7 @@ typedef struct freecell_solver_instance
* The debug_iter_output variables provide a programmer programmable way
* to debug the algorithm while it is running. This works well for DFS
* and Soft-DFS scans but at present support for A* and BFS is not
* too good, as its hard to tell which state came from which parent state.
*
* debug_iter_output is a flag that indicates whether to use this feature
* at all.
@@ -190,7 +190,7 @@ typedef struct freecell_solver_instance
int depth,
void * instance,
fcs_state_with_locations_t * state,
- int parent_iter_num
+ int tqparent_iter_num
);
void * debug_iter_output_context;
@@ -582,7 +582,7 @@ struct freecell_solver_soft_thread_struct
/*
* The priority queue of the A* scan */
- PQUEUE * a_star_pqueue;
+ PTQUEUE * a_star_pqueue;
double a_star_initial_cards_under_sequences;
/*
@@ -683,7 +683,7 @@ typedef struct freecell_solver_soft_thread_struct freecell_solver_soft_thread_t;
#define FCS_A_STAR_WEIGHT_CARDS_OUT 0
#define FCS_A_STAR_WEIGHT_MAX_SEQUENCE_MOVE 1
#define FCS_A_STAR_WEIGHT_CARDS_UNDER_SEQUENCES 2
-#define FCS_A_STAR_WEIGHT_SEQS_OVER_RENEGADE_CARDS 3
+#define FCS_A_STAR_WEIGHT_SETQS_OVER_RENEGADE_CARDS 3
#define FCS_A_STAR_WEIGHT_DEPTH 4
freecell_solver_instance_t * freecell_solver_alloc_instance(void);
@@ -170,7 +170,7 @@ typedef struct freecell_solver_instance
* to debug the algorithm while it is running. This works well for DFS
* and Soft-DFS scans but at present support for A* and BFS is not
- * too good, as its hard to tell which state came from which parent state.
+ * too good, as its hard to tell which state came from which tqparent state.
*
* debug_iter_output is a flag that indicates whether to use this feature